import React from 'react';

const Documentation = () => {
  return (
    <div className="documentation-container">
        <section id="documentation" className="documentation-section">
            <h1 className="title">AI Virtual Assistant - Internship Students 2024</h1>
            <h2 className="subtitle">General planning:</h2>
            <p className="paragraph">
              We are currently in the process of developing a Python application that leverages HTML and CSS to create an intuitive graphical user interface (GUI). This application will integrate multiple AI models through API calls, enabling users to effortlessly switch between different models tailored for specific tasks, such as coding, mathematics, and language processing. A key feature of our design is that the application will be capable of running locally, ensuring that users can access its functionality without the need for an internet connection.
            </p>
            <p className="paragraph">
              Upon receiving our assignment, we initiated the project by outlining a detailed timeline for each task to ensure a structured approach to development. This timeline serves as a roadmap, helping us allocate resources effectively and track our progress. Following this planning phase, Patrick_Pluto took the lead in creating the repository, establishing a centralized location for our codebase. Meanwhile, Yasin and sageTheDM forked the repository to begin their contributions, allowing them to work on specific features and enhancements independently.
            </p>
            <p className="paragraph">
              As we move forward, our focus will be on refining the user experience, optimizing the integration of AI models, and ensuring that the application is robust and user-friendly. We are excited about the potential of this project and are committed to delivering a high-quality application that meets the needs of our users.
            </p>

            <h2 className="subtitle">Frontend planning:</h2>
            <p className="paragraph">
              We are committed to designing a visually appealing graphical user interface (GUI) that significantly enhances user experience and engagement. The GUI will prominently feature a chat function, allowing users to interact seamlessly with the AI Assistant. This conversational interface will facilitate easy communication, making it intuitive for users to ask questions and receive responses.
            </p>
            <p className="paragraph">
              To further improve usability, we will incorporate distinct buttons that enable users to switch effortlessly between online and offline modes. This functionality ensures that users can access the AI's capabilities regardless of their internet connectivity, making the application versatile and accommodating to various user environments.
            </p>
            <p className="paragraph">
              Additionally, the interface will provide options for users to select from a range of AI models, each tailored for specific use cases such as coding assistance, mathematical problem-solving, and language translation. This feature empowers users to choose the most suitable AI for their needs, thereby enhancing the overall effectiveness and relevance of the application.
            </p>
            <p className="paragraph">
              We will also prioritize creating an intuitive layout, ensuring that all elements are easily accessible and visually coherent. By focusing on user experience in our design, we aim to make the application not only functional but also enjoyable to use. Our goal is to create a user-friendly environment that encourages exploration and interaction, ultimately leading to a more satisfying and productive experience for all users.
            </p>

            <h2 className="subtitle">Draw.io:</h2>
            <img src="/img/Live-Message-Idee.jpg" alt='Live Message Skizze' />

            <h2 className="subtitle">Inspiration:</h2>
            <p className="paragraph">We got our inspiration from Huggingchat.</p>

            <h2 className="subtitle">First prototype:</h2>
            <p className="paragraph">
              After prototyping the Website we started working on optimizing the css and html structure, and combining the front and the backend together with each other using Flask. Since we have never once done that once it was more learning by doing than planning that is why we have not planned this step but documented it.
            </p>

            <h2 className="subtitle">Web APP</h2>
            <h3 className="subsection-title">QtWebEngine 5</h3>
            <p className="paragraph">
              We decided on going with QtWebEngine, because Qt is cross platform, and easy to use. QtWebEngine is basically a slimmed down version of Chromium that runs on the Qt Widget Framework. It looked pretty good, but the browser part is very barebones, so it broke a lot of styling.
            </p>
            
            <h3 className="subsection-title">Styling</h3>
            <p className="paragraph">
              After conducting thorough testing, we discovered that even after performing a browser reset, the web application exhibited a distinct styling compared to the web version. This inconsistency prompted us to undertake a comprehensive overhaul of the entire CSS framework.
            </p>
            <p className="paragraph">
              In our redesign, we focused on enhancing the user experience by implementing custom scrollbars that align with our overall aesthetic. Additionally, we expanded upon our existing design foundation to ensure a more cohesive and visually appealing interface.
            </p>
            <p className="paragraph">
              Our efforts have resulted in a web application that is not only visually consistent across different platforms but also optimized for performance. The revamped web app is designed to be responsive, making it accessible and functional on a wide range of devices, from desktops to tablets and smartphones. This adaptability ensures that users can enjoy a seamless experience, regardless of the device they choose to use.
            </p>
            <p className="paragraph">
              Overall, these improvements reflect our commitment to delivering a high-quality product that meets the diverse needs of our users while maintaining a polished and professional appearance.
            </p>

            <h2 className="subtitle">Prototype: 17.09.2024</h2>
            <p className="paragraph">
              Our current prototype operates on a straightforward Python backend, which, while functional, relies heavily on our optimism that it will remain stable and not encounter any critical failures or data loss.
            </p>
            <p className="paragraph">
              The existing chat system is equipped with several key features designed to enhance user interaction. Users can easily resend the AI's response, allowing for quick follow-up questions or clarifications. Additionally, the system provides the ability to edit user messages, ensuring that any mistakes can be corrected without starting the conversation anew.
            </p>
            <p className="paragraph">
              Furthermore, users have the option to copy the AI's responses, facilitating easy sharing or saving of information for future reference. These features aim to create a more flexible and user-friendly experience, allowing for seamless communication and interaction with the AI.
            </p>
            <p className="paragraph">
              While the current setup serves as a solid foundation, we recognize the need for further improvements and enhancements to ensure reliability and robustness as we move forward in the development process.
            </p>
            <p className="paragraph">
              Theoretically there is also voice recognition but let us ignore that for now.
            </p>

            <h2 className="subtitle">17.09.2024</h2>
            <p className="paragraph">
              After transitioning to React, we made several significant changes. We renamed our History and Models components to .left-panel, which can now be hidden when not in use. Additionally, with various optimizations through React, we’ve successfully split the CSS and HTML components into more manageable parts.
            </p>
            <p className="paragraph">
              We also made our first strides towards achieving a fully responsive website. With these changes, we are well on our way to completing the responsive design in the near future.
            </p>

            <h2 className="subtitle">Backend planning:</h2>
            <h3 className="subsection-title">Task:</h3>
            <p className="paragraph">
              We will develop an extensible backend that enables us to easily swap out different AI models, facilitating the creation of a versatile AI Virtual Assistant. This architecture will allow for seamless integration of new AI technologies as they become available, ensuring that our application remains up-to-date and capable of meeting diverse user needs.
            </p>
            <p className="paragraph">
              The backend will also incorporate advanced features such as speech recognition, allowing users to interact with the AI Assistant through voice commands for a more natural and intuitive experience. Additionally, we will implement functionality to save chat histories, enabling users to revisit previous conversations and maintain continuity in their interactions with the AI.
            </p>
            <p className="paragraph">
              For the AI model, we will utilize Microsoft Phi 3.5, which offers robust capabilities for understanding and generating human-like responses. This choice will enhance the overall performance of the Virtual Assistant, making it a valuable tool for users seeking assistance across various tasks and topics. By combining an extensible backend with powerful AI capabilities, we aim to deliver a comprehensive and user-friendly virtual assistant experience.
            </p>

            <h2 className="subtitle">Design Philosophy:</h2>
            <p className="paragraph">
              Our design philosophy is to create one script file per feature. This allows us to possibly reuse certain features in other projects very easily, as we can copy the individual .py files, which all work on their own, except the specific .py file for this project, which is specially tailored towards this AI chatbot.
            </p>

            <h2 className="subtitle">UML diagrams:</h2>
            <p className="paragraph">Insert your UML diagrams here, one picture per diagram.</p>

            <h2 className="subtitle">First Prototype:</h2>
            <p className="paragraph">
              You are able to simply select an AI Model, then type out what you want to ask. This Prototype is already ready to answer questions and detect what language you write in and give the answer in the corresponding language.
            </p>

            <h2 className="subtitle">Combining back and frontend</h2>
            <h3 className="subsection-title">Flask setup</h3>
            <p className="paragraph">
              The flask setup was relatively quick. We had to adjust all of the file references, and add /static
            </p>
        </section>
    </div>
  );
};

export default Documentation;
